<template>
  <div class="full-page bg">
    <div
      v-loading.fullscreen.lock="markLoading"
      class="search-container"
      element-loading-background="rgba(255,255,255, 0.5)"
      element-loading-spinner="el-icon-loading"
      element-loading-text="数据加载中..."
    >
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        style="width: 100%"
      >
        <el-row :gutter="20">
          <el-col :span="5">
            <el-form-item label="专项小组">
              <el-select
                v-model="querys[2].value"
                placeholder="请选择专项小组"
                clearable
                style="width: 100%"
              >
                <el-option
                  v-for="(item, index) in groupNameOptions"
                  :key="index"
                  :label="item.label"
                  :value="item.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="审核状态">
              <dict-select
                v-model="querys[1].value"
                :hasDefaultOption="true"
                clearable
                dictCode="sjggqk_shzt"
                placeholder="请选择审核状态"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="填报时间">
              <el-date-picker
                v-model="querys[0].value"
                :default-time="['00:00:00', '23:59:59']"
                align="right"
                clearable
                end-placeholder="结束日期"
                placeholder="请选择填报日期"
                start-placeholder="开始日期"
                type="datetimerange"
                value-format="yyyy-MM-dd HH:mm:ss"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button
              class="btn btn-plus"
              icon="el-icon-search"
              type="primary"
              @click="handleSearch(1)"
            >
              搜索
            </el-button>
<!--            <el-button-->
<!--              class="btn btn-plus"-->
<!--              icon="el-icon-search"-->
<!--              type="primary"-->
<!--              @click="clearSearchForm()"-->
<!--            >-->
<!--              重置-->
<!--            </el-button>-->
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" class="main-table-container flex">
      <el-col
        ref="contentPanel"
        :span="24"
        class="table-container"
        style="padding: 20px"
      >
        <div ref="btnPanel" style="margin-bottom: 10px">
          <el-button
            class="btn btn-plus"
            icon="el-icon-plus"
            type="primary"
            @click="handleDbClick(null, '新增')"
          >
            {{ this.$t('common.add') }}
          </el-button>
          <el-button
            slot="reference"
            :disabled="!multipleSelection.length > 0"
            icon="el-icon-delete"
            type="danger"
            @click="handleDelete"
          >
            {{ this.$t('common.delete') }}
          </el-button>
        </div>
        <div :style="{width: '100%', height: `${tableMaxHeight}` + 'px'}">
          <el-table
            ref="multipleSelection"
            v-loading="loading"
            :data="tableData"
            :max-height="tableMaxHeight"
            :style="{width: '100%'}"
            size="mini"
            stripe
            @selection-change="handleSelectionChange"
          >
            <el-table-column
              :selectable="selectHandle"
              align="center"
              type="selection"
              width="55"
            ></el-table-column>
            <el-table-column
              align="center"
              label="市级部门"
              prop="unitName"
              show-overflow-tooltip
            >
            </el-table-column>
            <el-table-column prop="groupName" min-width="100" show-overflow-tooltip label="专项小组"
               align="center">
            </el-table-column>
            <el-table-column
              align="center"
              label="填报时间"
              prop="createTime"
              show-overflow-tooltip
            >
            </el-table-column>
            <el-table-column show-overflow-tooltip label="审核状态" align="center">
              <template v-slot="{ row }">
                <el-tag :type="!row.status
                                    ? 'info'
                                    : row.status === 1 ||
                                        row.status === 3 ||
                                          row.status === 5
                                        ? ''
                                        : row.status === 2 ||
                                            row.status === 4 ||
                                            row.status === 6
                                            ? 'danger'
                                            : row.status === 7
                                                ? 'success'
                                                : ''
                                    ">
                  {{ getDictName('sjggqk_shzt', row.status) }}
                </el-tag>
              </template>
            </el-table-column>
            <el-table-column
              align="center"
              fixed="right"
              label="操作"
              show-overflow-tooltip
              width="250"
            >
              <template v-slot="{ row }">
                <el-link v-if="row.status === 0" icon="el-icon-s-check" type="primary" :underline="false"
                         class="cloumn-btn" @click="handleVerify(row)">
                  上报
                </el-link>
                <el-link
                  v-if="row.status === 0 || row.status === 2 || row.status === 4 || row.status === 6"
                  :underline="false"
                  class="cloumn-btn"
                  icon="el-icon-edit"
                  type="primary"
                  @click="handleDbClick(row, '编辑')"
                >
                  编辑
                </el-link>
                <el-link v-if="row.status === 1" icon="el-icon-refresh-left" type="danger" :underline="false"
                         class="cloumn-btn withdraw" @click="revocation(row)">
                  撤回
                </el-link>
                <el-link v-if="row.status !== 2 && row.status !== 4 && row.status !== 6" icon="el-icon-view" type="primary" :underline="false" class="cloumn-btn"
                         @click="handleDbClick(row, '详情')">
                  详情
                </el-link>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <pagination
          ref="paginationPanel"
          :pageResult="queryParam.pageBean"
          style="margin-top: 10px"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
        />
      </el-col>
    </el-row>
    <cityProjectDialog
      ref="ProjectsDialog"
      @getData="getData"
    ></cityProjectDialog>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import projectsAPI from '@/api/municipalReform/index.js'
import auditApi from '@/api/ReformSituation/reformAudit'
import cityProjectDialog from './components/cityProjectDialog.vue'
import utils from '@/utils'

export default {
  name: 'ProjectCreateEntry',
  components: {
    pagination,
    cityProjectDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      searchForm: {},
      loading: false,
      tableData: [],
      multipleSelection: [],
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'CREATE_TIME_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'STATUS_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'group_name_',
          relation: 'AND',
          value: '',
        },
      ],
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        }
      },
      groupNameOptions: [
        {
          label: '党建统领体制改革专项小组',
          value: '党建统领体制改革专项小组'
        },
        {
          label: '经济体制改革专项小组',
          value: '经济体制改革专项小组'
        },
        {
          label: '社会民生领域改革专项小组',
          value: '社会民生领域改革专项小组'
        },
        {
          label: '民主与法制领域改革专项小组',
          value: '民主与法制领域改革专项小组'
        },
        {
          label: '文化体制改革专项小组',
          value: '文化体制改革专项小组'
        },
        {
          label: '平安法治领域改革专项小组',
          value: '平安法治领域改革专项小组'
        },
        {
          label: '其他',
          value: '其他'
        }
      ]
    }
  },
  created() {
    this.getData()
  },
  computed: {
    statusChange() {
      return status => {
        switch (status) {
          case 0:
            return '草稿'
          case 1:
            return '提交本级审核'
          case 2:
            return '提交本级驳回'
          case 3:
            return '提交专项小组审核'
          case 4:
            return '专项小组审核驳回'
          case 5:
            return '提交改革办核准'
          case 6:
            return '改革办核准驳回'
          case 7:
            return '改革办核准通过'
          default:
            return '草稿'
        }
      }
    }
  },
  mounted() {},
  methods: {
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    selectHandle(row) {
      if (row.status != 1) {
        return true
      }
    },
    handleSearch(page) {
      this.queryParam.querys = []
      this.querys.forEach(item => {
        if (item.value !== undefined) {
          this.queryParam.querys.push(item)
        }
      })
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.getData()
    },
    //获取数据
    getData() {
      this.loading = true
      this.tableData = []
      this.queryParam.querys = this.querys
      auditApi.departmentAudit(this.queryParam,false).then(res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParam.pageBean.page = res.page
          this.queryParam.pageBean.total = res.total
          this.$set(this.tableData)
          this.loading = false
        }
      })
    },
    //删除
    handleDelete() {
      this.$confirm(this.$t('common.sureDelete'), this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'error'
      })
        .then(() => {
          this.markLoading = true
          let ids = this.multipleSelection.join(',')
          projectsAPI.deleteData(ids).then(res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: '删除成功',
                duration: 2000
              })
              this.getData()
            }
            this.markLoading = false
          })
        })
        .catch(() => {})
    },
    //修改
    handleDbClick(data, title) {
      this.$refs.ProjectsDialog.open(data, title)
    },
    //表格选中
    handleSelectionChange(val) {
      this.multipleSelection = []
      this.$refs.multipleSelection.selection.forEach(item => {
        this.multipleSelection.push(item.id)
      })
    },
    //展示数量
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.handleSearch(1)
    },
    //表格页数
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.handleSearch(val)
    },
    // 撤回
    revocation(item) {
      let data = {
        status: 0,
        id: item.id
      }
      this.$confirm('确认执行撤销操作吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'error'
      }).then(() => {
        this.markLoading = true
        auditApi.updateMunStatus(data, res => {
          if (res.state) {
            this.$message.success('撤销操作成功')
            this.handleSearch(1)
          }
          this.markLoading = false
        })

      }).catch(()=>{})
    },

    // 上报
    handleVerify(item) {
      let data = {
        status: 1,
        id: item.id,
      }
      this.$confirm('确认上报吗？', this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'success'
      }).then(() => {
        this.markLoading = true
        auditApi.updateMunStatus(data, res => {
          if (res.state) {
            item.status = 1
            this.$message.success('上报成功')
          }
          this.markLoading = false
        })
      }).catch(()=>{})
    },
  }
}
</script>

<style lang="scss" scoped>
.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(2) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }

  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}
</style>
